@@ -3,7 +3,6 @@ import logging
 import os
 import tempfile
 import threading
-import time
 from functools import wraps
 
 from pyvertica.connection import get_connection
@@ -249,6 +248,9 @@ class VerticaBatch(object):
             logging.error('Terminating thread timed out!')
 
         self._in_batch = False
+        os.remove(self._fifo_path)
+        os.rmdir(os.path.dirname(self._fifo_path))
+
         logger.info('Batch ended')
         return ended_clean
 
